# coding=utf-8
# Copyright 2020 The TensorFlow Datasets Authors.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""Structured datasets."""

from tensorflow_datasets.structured.amazon_us_reviews import AmazonUSReviews
from tensorflow_datasets.structured.forest_fires import ForestFires
from tensorflow_datasets.structured.genomics_ood import GenomicsOod
from tensorflow_datasets.structured.german_credit_numeric import GermanCreditNumeric
from tensorflow_datasets.structured.higgs import Higgs
from tensorflow_datasets.structured.iris import Iris
from tensorflow_datasets.structured.movielens import Movielens
from tensorflow_datasets.structured.radon import Radon
from tensorflow_datasets.structured.rock_you import RockYou
from tensorflow_datasets.structured.titanic import Titanic
from tensorflow_datasets.structured.wine_quality import WineQuality
